Function crashpad_sys::handler_name [−][src]
pub const fn handler_name() -> &'static strExpand description
The default file name of the Crashpad handler executable binary.
pub const fn handler_name() -> &'static strThe default file name of the Crashpad handler executable binary.