Function crashpad_sys::precompiled_handler [−][src]
pub const fn precompiled_handler() -> Option<&'static [u8]>Expand description
The data of a precompiled Crashpad handler executable binary.
pub const fn precompiled_handler() -> Option<&'static [u8]>The data of a precompiled Crashpad handler executable binary.